<?php
/* Define the custom box */

add_action( 'add_meta_boxes', 'swift_add_custom_box' );

// backwards compatible (before WP 3.0)
// add_action( 'admin_init', 'swift_add_custom_box', 1 );

/* Do something with the data entered */
add_action( 'save_post', 'swift_save_postdata' );

/* Adds a box to the main column on the Post and Page edit screens */
function swift_add_custom_box() {
add_meta_box( 'hide_title', __('Swift CMS options', 'swift'), 'swift_post_meta_hide_title', 'page', 'side', 'high', '' );
add_meta_box( 'custom_css', __('Custom CSS for this page', 'swift'), 'swift_page_css', 'page', 'normal', 'high', '' );
}

/* Prints the box content */
function swift_post_meta_hide_title( $post ) {

  // Use nonce for verification
  wp_nonce_field( ( __FILE__ ), 'swift_noncename' );

  get_post_meta( $post->ID,'_swift_hide_title',true);
  
  if( get_post_meta( $post->ID,'_swift_hide_title',true) )
  $checked = 'checked="yes"';
  else 
  $checked = '';
  
  // The actual fields for data entry
  echo '<input type="checkbox" id="swift_hide_title" name="swift_hide_title" value="TRUE" '.$checked.' />&nbsp;';
  echo '<label for="swift_hide_title">';
       _e("Hide post title", 'swift' );
  echo '</label> <br /><br />';
  
  if( get_post_meta( $post->ID,'_swift_disable_oversmart_tinymce',true) )
  $checked = 'checked="yes"';
  else 
  $checked = '';
  
  echo '<input type="checkbox" id="swift_disable_oversmart_tinymce" name="swift_disable_oversmart_tinymce" value="TRUE" '.$checked.' />&nbsp;';
  echo '<label for="swift_disable_oversmart_tinymce">';
       _e('Prevent WordPress from adding </label>&lt;p&gt; and  removing &lt;br /&gt; tags.', 'swift' );
  echo '</label> ';
}

function swift_page_css( $post ){
 // Use nonce for verification
  wp_nonce_field( ( __FILE__ ), 'swift_noncename' );

  // The actual fields for data entry
  echo '<textarea name="swift_page_css" style="width:100%;height:120px;">'.get_post_meta( $post->ID,'_swift_page_css',true).'</textarea><br />';
  echo '<label for="swift_page_css">';
       _e("You can add page specific CSS here", 'swift' );
  echo '</label> <br />';
  	
}

/* When the post is saved, saves our custom data */
function swift_save_postdata( $post_id ) {
  // verify if this is an auto save routine. 
  // If it is our form has not been submitted, so we dont want to do anything
  if ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE ) 
      return;

  // verify this came from the our screen and with proper authorization,
  // because save_post can be triggered at other times

 /* if ( !wp_verify_nonce( $_POST['swift_noncename'], plugin_basename( __FILE__ ) ) )
      return;
*/
  
  // Check permissions
  if ( isset($_POST['post_type']) && 'page' == $_POST['post_type'] ) 
  {
    if ( !current_user_can( 'edit_page', $post_id ) )
        return;
  }
  else
  {
    if ( !current_user_can( 'edit_post', $post_id ) )
        return;
  }

  // OK, we're authenticated: we need to find and save the data

  
	if( isset($_POST['swift_hide_title']) && $_POST['swift_hide_title'] == TRUE ){
		update_post_meta( $post_id, '_swift_hide_title', TRUE );
	}else{
		update_post_meta( $post_id, '_swift_hide_title', FALSE );
	}  
	
	if( isset($_POST['swift_disable_oversmart_tinymce']) && $_POST['swift_disable_oversmart_tinymce'] == TRUE ){
		update_post_meta( $post_id, '_swift_disable_oversmart_tinymce', TRUE );
	}else{
		update_post_meta( $post_id, '_swift_disable_oversmart_tinymce', FALSE );
	}
	
	if( isset($_POST['swift_page_css']) ){
		update_post_meta( $post_id, '_swift_page_css', esc_textarea ($_POST['swift_page_css']) );
	}
	
}
?>