<?php
/**
 * Text widget without padding
 *
 * @since 6.0
 */
class Swift_Widget_Text_No_Styling extends WP_Widget {

	function __construct() {
		$widget_ops = array('classname' => 'widget_text_nopadding', 'description' => __('Arbitrary text or HTML', 'swift'));
		$control_ops = array('width' => 400, 'height' => 350);
		parent::__construct('text-no-styling', __('Text without padding and border', 'swift'), $widget_ops, $control_ops);
	}

	function widget( $args, $instance ) {
		extract($args);
		$title = apply_filters( 'widget_title', empty($instance['title']) ? '' : $instance['title'], $instance, $this->id_base);
		$text = apply_filters( 'widget_text', $instance['text'], $instance );
		echo $before_widget;
		if ( !empty( $title ) ) { echo $before_title . $title . $after_title; } ?>
			<div class="textwidget nopadding"><?php echo $instance['filter'] ? wpautop($text) : $text; ?></div>
		<?php
		echo $after_widget;
	}

	function update( $new_instance, $old_instance ) {
		$instance = $old_instance;
		$instance['title'] = strip_tags($new_instance['title']);
		if ( current_user_can('unfiltered_html') )
			$instance['text'] =  $new_instance['text'];
		else
			$instance['text'] = stripslashes( wp_filter_post_kses( addslashes($new_instance['text']) ) ); // wp_filter_post_kses() expects slashed
		$instance['filter'] = isset($new_instance['filter']);
		return $instance;
	}

	function form( $instance ) {
		$instance = wp_parse_args( (array) $instance, array( 'title' => '', 'text' => '' ) );
		$title = strip_tags($instance['title']);
		$text = esc_textarea($instance['text']);
?>
		<p><label for="<?php echo $this->get_field_id('title'); ?>"><?php _e('Title:', 'swift'); ?></label>
		<input class="widefat" id="<?php echo $this->get_field_id('title'); ?>" name="<?php echo $this->get_field_name('title'); ?>" type="text" value="<?php echo esc_attr($title); ?>" /></p>

		<textarea class="widefat" rows="16" cols="20" id="<?php echo $this->get_field_id('text'); ?>" name="<?php echo $this->get_field_name('text'); ?>"><?php echo $text; ?></textarea>

		<p><input id="<?php echo $this->get_field_id('filter'); ?>" name="<?php echo $this->get_field_name('filter'); ?>" type="checkbox" <?php checked(isset($instance['filter']) ? $instance['filter'] : 0); ?> />&nbsp;<label for="<?php echo $this->get_field_id('filter'); ?>"><?php _e('Automatically add paragraphs', 'swift'); ?></label></p>
<?php
	}
}

/**
 * HomePage only text widget
 *
 * @since 6.0
 */
class Swift_Widget_Text_Home extends WP_Widget {

	function __construct() {
		$widget_ops = array('classname' => 'widget_text', 'description' => __('Display text only on the home page', 'swift'));
		$control_ops = array('width' => 400, 'height' => 350);
		parent::__construct('text-home', __('Homepage only text widget', 'swift'), $widget_ops, $control_ops);
	}

	function widget( $args, $instance ) {
		if( is_home() ):
		extract($args);
		$title = apply_filters( 'widget_title', empty($instance['title']) ? '' : $instance['title'], $instance, $this->id_base);
		$text = apply_filters( 'widget_text', $instance['text'], $instance );
		echo $before_widget;
		if ( !empty( $title ) ) { echo $before_title . $title . $after_title; } ?>
			<div class="textwidget"><?php echo $instance['filter'] ? wpautop($text) : $text; ?></div>
		<?php
		echo $after_widget;
		endif;
	}

	function update( $new_instance, $old_instance ) {
		$instance = $old_instance;
		$instance['title'] = strip_tags($new_instance['title']);
		if ( current_user_can('unfiltered_html') )
			$instance['text'] =  $new_instance['text'];
		else
			$instance['text'] = stripslashes( wp_filter_post_kses( addslashes($new_instance['text']) ) ); // wp_filter_post_kses() expects slashed
		$instance['filter'] = isset($new_instance['filter']);
		return $instance;
	}

	function form( $instance ) {
		$instance = wp_parse_args( (array) $instance, array( 'title' => '', 'text' => '' ) );
		$title = strip_tags($instance['title']);
		$text = esc_textarea($instance['text']);
?>
		<p><label for="<?php echo $this->get_field_id('title'); ?>"><?php _e('Title:', 'swift'); ?></label>
		<input class="widefat" id="<?php echo $this->get_field_id('title'); ?>" name="<?php echo $this->get_field_name('title'); ?>" type="text" value="<?php echo esc_attr($title); ?>" /></p>

		<textarea class="widefat" rows="16" cols="20" id="<?php echo $this->get_field_id('text'); ?>" name="<?php echo $this->get_field_name('text'); ?>"><?php echo $text; ?></textarea>

		<p><input id="<?php echo $this->get_field_id('filter'); ?>" name="<?php echo $this->get_field_name('filter'); ?>" type="checkbox" <?php checked(isset($instance['filter']) ? $instance['filter'] : 0); ?> />&nbsp;<label for="<?php echo $this->get_field_id('filter'); ?>"><?php _e('Automatically add paragraphs', 'swift'); ?></label></p>
<?php
	}
}
/**
 * Page specific text widget
 *
 * @since 6.0
 */
class Swift_Widget_Text_Page_Specific extends WP_Widget {

	function __construct() {
		$widget_ops = array('classname' => 'widget_text', 'description' => __('Display text only on some pages', 'swift'));
		$control_ops = array('width' => 400, 'height' => 350);
		parent::__construct('text-page-specific', __('Page specific text widget', 'swift'), $widget_ops, $control_ops);
	}

	function widget( $args, $instance ) {
		if( is_page($instance['pages']) ):
		extract($args);
		$title = apply_filters( 'widget_title', empty($instance['title']) ? '' : $instance['title'], $instance, $this->id_base);
		$text = apply_filters( 'widget_text', $instance['text'], $instance );
		echo $before_widget;
		if ( !empty( $title ) ) { echo $before_title . $title . $after_title; } ?>
			<div class="textwidget"><?php echo $instance['filter'] ? wpautop($text) : $text; ?></div>
		<?php
		echo $after_widget;
		endif;
	}

	function update( $new_instance, $old_instance ) {
		$instance = $old_instance;
		$instance['title'] = strip_tags($new_instance['title']);
		if ( current_user_can('unfiltered_html') )
			$instance['text'] =  $new_instance['text'];
		else
			$instance['text'] = stripslashes( wp_filter_post_kses( addslashes($new_instance['text']) ) ); // wp_filter_post_kses() expects slashed
		$instance['filter'] = isset($new_instance['filter']);
		
		$instance['pages'] = $new_instance['pages'];
		
		return $instance;
	}

	function form( $instance ) {
		$instance = wp_parse_args( (array) $instance, array( 'title' => '', 'text' => '','pages' => '' ) );
		$title = strip_tags($instance['title']);
		$text = esc_textarea($instance['text']);
				
		if( is_array($instance['pages']))
		
		foreach($instance['pages'] as $selected)
		$selected_pages[] =  $selected;

					 $pages = get_pages();
		_e('<h4>Select the pages on which you want this widget to appear</h4>', 'swift');
		?>
		<style>
		ul.swift_multiselect li{
		list-style:none;float:left;width:50%}
		ul.swift_multiselect .checkbox{padding:5px;margin-right:10px}
		</style><ul class="swift_multiselect"><?php 
		
  			foreach ( $pages as $pagg ) {
		 	if( isset($selected_pages) && is_array($selected_pages) && in_array( $pagg->ID, $selected_pages ))
		 	$checked = 'checked';
		 	else 
		 	$checked = '';
		 	
  			$option = '<li><input class="checkbox" name="'.$this->get_field_name('pages').'[]" type="checkbox" value="' . $pagg->ID . '" id="p_' . $pagg->ID . '" '.$checked.'>';
			$option .= '<label for="p_' . $pagg->ID . '">'.$pagg->post_title.'</label>';
			$option .= '</li>';
			echo $option;
 		 }
 		 ?>
 		 </ul>
 		 <div class="clear"></div>
		<p><label for="<?php echo $this->get_field_id('title'); ?>"><?php _e('Title:', 'swift'); ?></label>
		<input class="widefat" id="<?php echo $this->get_field_id('title'); ?>" name="<?php echo $this->get_field_name('title'); ?>" type="text" value="<?php echo esc_attr($title); ?>" /></p>

		<textarea class="widefat" rows="16" cols="20" id="<?php echo $this->get_field_id('text'); ?>" name="<?php echo $this->get_field_name('text'); ?>"><?php echo $text; ?></textarea>

		<p><input id="<?php echo $this->get_field_id('filter'); ?>" name="<?php echo $this->get_field_name('filter'); ?>" type="checkbox" <?php checked(isset($instance['filter']) ? $instance['filter'] : 0); ?> />&nbsp;<label for="<?php echo $this->get_field_id('filter'); ?>"><?php _e('Automatically add paragraphs', 'swift'); ?></label></p>
<?php
	}
}

/**
 * Category specific text widget
 *
 * @since 6.0
 */
class Swift_Widget_Text_Category_Specific extends WP_Widget {

	function __construct() {
		$widget_ops = array('classname' => 'widget_text', 'description' => __('Display text only on some categories', 'swift'));
		$control_ops = array('width' => 400, 'height' => 350);
		parent::__construct('text-category-specific', __('Category specific text widget', 'swift'), $widget_ops, $control_ops);
	}

	function widget( $args, $instance ) {
		if( in_category($instance['cats']) ):
		extract($args);
		$title = apply_filters( 'widget_title', empty($instance['title']) ? '' : $instance['title'], $instance, $this->id_base);
		$text = apply_filters( 'widget_text', $instance['text'], $instance );
		echo $before_widget;
		if ( !empty( $title ) ) { echo $before_title . $title . $after_title; } ?>
			<div class="textwidget"><?php echo $instance['filter'] ? wpautop($text) : $text; ?></div>
		<?php
		echo $after_widget;
		endif;
	}
	function update( $new_instance, $old_instance ) {
		$instance = $old_instance;
		$instance['title'] = strip_tags($new_instance['title']);
		if ( current_user_can('unfiltered_html') )
			$instance['text'] =  $new_instance['text'];
		else
			$instance['text'] = stripslashes( wp_filter_post_kses( addslashes($new_instance['text']) ) ); // wp_filter_post_kses() expects slashed
		$instance['filter'] = isset($new_instance['filter']);
		
		$instance['cats'] = $new_instance['cats'];
		
		return $instance;
	}

	function form( $instance ) {
		$instance = wp_parse_args( (array) $instance, array( 'title' => '', 'text' => '','cats' => '' ) );
		$title = strip_tags($instance['title']);
		$text = esc_textarea($instance['text']);
				
		if( is_array($instance['cats']))
		
		foreach($instance['cats'] as $selected)
		$selected_cats[] =  $selected;

		$cats = get_categories( );
				
		_e('<h4>Select the pages on which you want this widget to appear</h4>', 'swift');
		?>
		<style>
		ul.swift_multiselect_cat li{
		list-style:none;float:left;width:33%}
		ul.swift_multiselect_cat .checkbox{padding:5px;margin-right:10px}
		</style><ul class="swift_multiselect_cat"><?php 
		
  			foreach ( $cats as $cat ) {
		 	if( isset($selected_cats) && is_array($selected_cats) && in_array( $cat->cat_ID, $selected_cats ))
		 	$checked = 'checked';
		 	else 
		 	$checked = '';
		 	
  			$option = '<li><input class="checkbox" name="'.$this->get_field_name('cats').'[]" type="checkbox" value="' . $cat->cat_ID . '" id="c_' . $cat->cat_ID . '" '.$checked.'>';
			$option .= '<label for="p_' . $cat->cat_ID . '">'.$cat->name.'</label>';
			$option .= '</li>';
			echo $option;
 		 }
 		 ?>
 		 </ul>
 		 <div class="clear"></div>
		<p><label for="<?php echo $this->get_field_id('title'); ?>"><?php _e('Title:', 'swift'); ?></label>
		<input class="widefat" id="<?php echo $this->get_field_id('title'); ?>" name="<?php echo $this->get_field_name('title'); ?>" type="text" value="<?php echo esc_attr($title); ?>" /></p>

		<textarea class="widefat" rows="16" cols="20" id="<?php echo $this->get_field_id('text'); ?>" name="<?php echo $this->get_field_name('text'); ?>"><?php echo $text; ?></textarea>

		<p><input id="<?php echo $this->get_field_id('filter'); ?>" name="<?php echo $this->get_field_name('filter'); ?>" type="checkbox" <?php checked(isset($instance['filter']) ? $instance['filter'] : 0); ?> />&nbsp;<label for="<?php echo $this->get_field_id('filter'); ?>"><?php _e('Automatically add paragraphs', 'swift'); ?></label></p>
<?php
	}
}

/**
 * Swift_Popular_Posts widget class
 *
 * @since 6.0
 */
class Swift_Popular_Posts extends WP_Widget {

	function __construct() {
		$widget_ops = array('classname' => 'widget_recent_entries', 'description' => __( 'The most popular posts on your site', 'swift' ) );
		parent::__construct('popular-posts', __('Popular posts', 'swift'), $widget_ops);
		$this->alt_option_name = 'widget_popular_entries';

		add_action( 'save_post', array(&$this, 'flush_widget_cache') );
		add_action( 'deleted_post', array(&$this, 'flush_widget_cache') );
		add_action( 'switch_theme', array(&$this, 'flush_widget_cache') );
	}
	
 	
	public $age;

	function widget($args, $instance) {
		$cache = wp_cache_get('widget_popular_posts', 'widget');

		if ( !is_array($cache) )
			$cache = array();

		if ( isset($cache[$args['widget_id']]) ) {
			echo $cache[$args['widget_id']];
			return;
		}

		ob_start();
		extract($args);

		$title = apply_filters('widget_title', empty($instance['title']) ? __('Popular Posts', 'swift' ) : $instance['title'], $instance, $this->id_base);
		if ( ! $number = absint( $instance['number'] ) )
 			$number = 10;
 			
		if ( ! $this->age = absint( $instance['age'] ) )
 			 $this->age = 10;

 	
		add_filter( 'posts_where',  array(&$this, 'query_where' ) );

		$r = new WP_Query(array('posts_per_page' => $number, 'no_found_rows' => true, 'post_status' => 'publish', 'ignore_sticky_posts' => true, 'orderby' => 'comment_count', 'order' => 'DESC'));

		remove_filter( 'posts_where', array(&$this, 'query_where' ) );
		
		if ($r->have_posts()) :
?>
		<?php echo $before_widget; ?>
		<?php if ( $title ) echo $before_title . $title . $after_title; ?>
		<ul>
		<?php  while ($r->have_posts()) : $r->the_post(); ?>
		<li>
			<?php  the_post_thumbnail( array(48,48), array('class' => 'alignleft widget-thumb' ));?>
			<a href="<?php the_permalink() ?>" title="<?php echo esc_attr(get_the_title() ? get_the_title() : get_the_ID()); ?>"><?php if ( get_the_title() ) the_title(); else the_ID(); ?></a>
			<br />
			<span class="widget-date"><a href="<?php echo esc_url( get_permalink() )?>" title="<?php echo esc_attr( get_the_time() )?>" rel="bookmark"><time class="entry-date" datetime="<?php echo esc_attr( get_the_date( 'c' ) )?>" pubdate><?php echo esc_html( get_the_date() )?></time></a></span>
			<div class="clear"></div>
		</li>
		<?php endwhile; ?>
		</ul>
		<?php echo $after_widget; ?>
<?php
		// Reset the global $the_post as this query will have stomped on it
		wp_reset_postdata();

		endif;

		$cache[$args['widget_id']] = ob_get_flush();
		wp_cache_set('widget_recent_posts', $cache, 'widget');
	}

	function update( $new_instance, $old_instance ) {
		$instance = $old_instance;
		$instance['title'] = strip_tags($new_instance['title']);
		$instance['number'] = (int) $new_instance['number'];
		$instance['images'] = (bool) $new_instance['images'];
		$instance['age'] = (int) $new_instance['age'];
		
		$this->flush_widget_cache();

		$alloptions = wp_cache_get( 'alloptions', 'options' );
		if ( isset($alloptions['widget_popular_entries']) )
			delete_option('widget_popular_entries');

		return $instance;
	}

	function flush_widget_cache() {
		wp_cache_delete('widget_popular_posts', 'widget');
	}
	
	function query_where($where = '' ){
		$where .= " AND post_date > '" . date('Y-m-d', strtotime('-'.$this->age.' days')) . "'";
		return $where;
	}
	
	function form( $instance ) {
		$title = isset($instance['title']) ? esc_attr($instance['title']) : '';
		$number = isset($instance['number']) ? absint($instance['number']) : 5;
		$images = isset($instance['images']) ? (bool)($instance['images']) : TRUE;
		$age = isset($instance['age']) ? absint($instance['age']) : 30;
		?>
		<p><label for="<?php echo $this->get_field_id('title', 'swift' ); ?>"><?php _e('Title:', 'swift' ); ?></label>
		<input class="widefat" id="<?php echo $this->get_field_id('title', 'swift' ); ?>" name="<?php echo $this->get_field_name('title', 'swift' ); ?>" type="text" value="<?php echo $title; ?>" /></p>

		<p><label for="<?php echo $this->get_field_id('number'); ?>"><?php _e('Number of posts to show:', 'swift' ); ?></label>
		<input id="<?php echo $this->get_field_id('number'); ?>" name="<?php echo $this->get_field_name('number'); ?>" type="text" value="<?php echo $number; ?>" size="3" /></p>
		
		<p><label for="<?php echo $this->get_field_id('age'); ?>"><?php _e('Show posts from last "n" days:', 'swift' ); ?></label>
		<input id="<?php echo $this->get_field_id('age'); ?>" name="<?php echo $this->get_field_name('age'); ?>" type="text" value="<?php echo $age; ?>" size="3" /></p>
		<p><i><label for="<?php echo $this->get_field_id('age'); ?>"><?php _e('Enter the value of "n" above', 'swift' ); ?></label></i></p>
		<br />
		<input class="checkbox" type="checkbox" <?php checked($images, true) ?> id="<?php echo $this->get_field_id('images'); ?>" name="<?php echo $this->get_field_name('images'); ?>" />
		<label for="<?php echo $this->get_field_id('images'); ?>"><?php _e('Show thumbnail', 'swift' ); ?></label><br />
		<?php
	}
}
/**
 * Swift_Random_Posts widget class
 *
 * @since 2.8.0
 */
class Swift_Random_Posts extends WP_Widget {

	function __construct() {
		$widget_ops = array('classname' => 'widget_random_posts', 'description' => __( 'Random posts from your site', 'swift' ) );
		parent::__construct('random-posts', __('Random posts', 'swift'), $widget_ops);
		$this->alt_option_name = 'widget_random_entries';

		add_action( 'save_post', array(&$this, 'flush_widget_cache') );
		add_action( 'deleted_post', array(&$this, 'flush_widget_cache') );
		add_action( 'switch_theme', array(&$this, 'flush_widget_cache') );
	}

	function widget($args, $instance) {
		$cache = wp_cache_get('widget_random_posts', 'widget');

		if ( !is_array($cache) )
			$cache = array();

		if ( isset($cache[$args['widget_id']]) ) {
			echo $cache[$args['widget_id']];
			return;
		}

		ob_start();
		extract($args);

		$title = apply_filters('widget_title', empty($instance['title']) ? __('Random Posts', 'swift' ) : $instance['title'], $instance, $this->id_base);
		if ( ! $number = absint( $instance['number'] ) )
 			$number = 10;

		$r = new WP_Query(array('posts_per_page' => $number, 'no_found_rows' => true, 'post_status' => 'publish', 'ignore_sticky_posts' => true, 'orderby' => 'rand'));
		if ($r->have_posts()) :
?>
		<?php echo $before_widget; ?>
		<?php if ( $title ) echo $before_title . $title . $after_title; ?>
		<ul>
		<?php  while ($r->have_posts()) : $r->the_post(); ?>
		<li>
			<?php  the_post_thumbnail( array(48,48), array('class' => 'alignleft widget-thumb' ));?>
			<a href="<?php the_permalink() ?>" title="<?php echo esc_attr(get_the_title() ? get_the_title() : get_the_ID()); ?>"><?php if ( get_the_title() ) the_title(); else the_ID(); ?></a>
			<br />
			<span class="widget-date"><a href="<?php echo esc_url( get_permalink() )?>" title="<?php echo esc_attr( get_the_time() )?>" rel="bookmark"><time class="entry-date" datetime="<?php echo esc_attr( get_the_date( 'c' ) )?>" pubdate><?php echo esc_html( get_the_date() )?></time></a></span>
			<div class="clear"></div>
		</li>
		<?php endwhile; ?>
		</ul>
		<?php echo $after_widget; ?>
<?php
		// Reset the global $the_post as this query will have stomped on it
		wp_reset_postdata();

		endif;

		$cache[$args['widget_id']] = ob_get_flush();
		wp_cache_set('widget_recent_posts', $cache, 'widget');
	}

	function update( $new_instance, $old_instance ) {
		$instance = $old_instance;
		$instance['title'] = strip_tags($new_instance['title']);
		$instance['number'] = (int) $new_instance['number'];
		$instance['images'] = (bool) $new_instance['images'];
		$this->flush_widget_cache();

		$alloptions = wp_cache_get( 'alloptions', 'options' );
		if ( isset($alloptions['widget_random_entries']) )
			delete_option('widget_random_entries');

		return $instance;
	}

	function flush_widget_cache() {
		wp_cache_delete('widget_random_posts', 'widget');
	}

	function form( $instance ) {
		$title = isset($instance['title']) ? esc_attr($instance['title']) : '';
		$number = isset($instance['number']) ? absint($instance['number']) : 5;
		$images = isset($instance['images']) ? (bool)($instance['images']) : TRUE;
?>
		<p><label for="<?php echo $this->get_field_id('title', 'swift' ); ?>"><?php _e('Title:', 'swift' ); ?></label>
		<input class="widefat" id="<?php echo $this->get_field_id('title', 'swift' ); ?>" name="<?php echo $this->get_field_name('title', 'swift' ); ?>" type="text" value="<?php echo $title; ?>" /></p>

		<p><label for="<?php echo $this->get_field_id('number'); ?>"><?php _e('Number of posts to show:', 'swift' ); ?></label>
		<input id="<?php echo $this->get_field_id('number'); ?>" name="<?php echo $this->get_field_name('number'); ?>" type="text" value="<?php echo $number; ?>" size="3" /></p>
		
		<input class="checkbox" type="checkbox" <?php checked($images, true) ?> id="<?php echo $this->get_field_id('images'); ?>" name="<?php echo $this->get_field_name('images'); ?>" />
		<label for="<?php echo $this->get_field_id('images'); ?>"><?php _e('Show thumbnail', 'swift' ); ?></label><br />
		<?php
	}
}

/**
 * Register all of the default Swift widgets on startup.
 *
 * Calls 'widgets_init' action after all of the Swift widgets have been
 * registered.
 *
 * @since 6.0
 */
function swift_widgets_init() {
	if ( !is_blog_installed() )
		return;

	//register_widget('Swift_Widget_Text_No_Styling');
	//register_widget('Swift_Widget_Text_Home');
	//register_widget('Swift_Widget_Text_Page_Specific');
	//register_widget('Swift_Widget_Text_Category_Specific');
	register_widget('Swift_Popular_Posts');
	//register_widget('Swift_Random_Posts');
	
}

add_action('widgets_init', 'swift_widgets_init', 1);

